@@ -10,15 +10,15 @@
     </message>
     <message>
         <source>Current theme: </source>
-        <translation type="unfinished"></translation>
+        <translation>Thème actuel: </translation>
     </message>
     <message>
         <source>Use custom (fast) window transitions</source>
-        <translation type="unfinished"></translation>
+        <translation>Utiliser les transitions (rapide) de fenêtre customisées</translation>
     </message>
     <message>
         <source>Setting up window transitions</source>
-        <translation type="unfinished"></translation>
+        <translation>Configurer les transitions de fenêtre</translation>
     </message>
     <message>
         <source>Export theme</source>
